@@ -1,8 +1,9 @@
 import kagefunc
 import vapoursynth as vs
 import vsdeband
+import vsutil
 
-from .internal import value_error
+from .internal import type_error, value_error
 
 core = vs.core
 
@@ -33,7 +34,7 @@ def RetinexDeband(
         or clip.format.sample_type != vs.INTEGER
         or clip.format.bits_per_sample > 16
     ):
-        raise value_error("currenly only supports 8-16 bit integer YUV input")
+        raise value_error("currently only supports 8-16 bit integer YUV input")
     mask_threshold = mask_threshold >> (16 - clip.format.bits_per_sample)
     mask = (
         kagefunc.retinex_edgemask(clip)
@@ -42,5 +43,13 @@ def RetinexDeband(
     )
     if showmask:
         return mask
-    deband = vsdeband.F3kdb(use_neo=True).deband(clip, thr=threshold, grains=0)
+    debander = vsdeband.F3kdb()
+    if debander.thr == 30:
+        # Because the latest version of vs-deband CHANGED THE SCALING of the threshold parameter...
+        raise type_error(
+            "please update to the latest git version of vs-deband: https://github.com/Irrational-Encoding-Wizardry/vs-deband"
+        )
+    deband = debander.deband(clip, thr=(threshold << 8), grains=0)
+    if clip.format.bits_per_sample != 16:
+        deband = vsutil.depth(deband, clip.format.bits_per_sample)
     return core.std.MaskedMerge(deband, clip, mask)
